pub struct SecretClientListSecretPropertiesOptions<'a> {
pub maxresults: Option<i32>,
pub method_options: PagerOptions<'a>,
}Expand description
Options to be passed to SecretClient::list_secret_properties()
Fields
maxresults: Option<i32>Maximum number of results to return in a page. If not specified the service will return up to 25 results.
method_options: PagerOptions<'a>Allows customization of the method call.
Implementations
Sourceimpl SecretClientListSecretPropertiesOptions<'_>
impl SecretClientListSecretPropertiesOptions<'_>
Sourcepub fn into_owned(self) -> SecretClientListSecretPropertiesOptions<'static>
pub fn into_owned(self) -> SecretClientListSecretPropertiesOptions<'static>
Transforms this SecretClientListSecretPropertiesOptions into a new SecretClientListSecretPropertiesOptions that owns the underlying data, cloning it if necessary.